pub struct CommandId(/* private fields */);Expand description
Fact collection types and stable identifiers into those collections. Stable identifier for a semantic command in the recorded command stream.
Implementations