pub struct GlobPatternBehavior { /* private fields */ }Expand description
Option-sensitive shell behavior enums reused by linter facts and rules. Option-sensitive pattern operators available to glob and shell-pattern facts.
Implementations
Sourceimpl GlobPatternBehavior
impl GlobPatternBehavior
Sourcepub const fn from_parts(
extended_glob: PatternOperatorBehavior,
ksh_glob: PatternOperatorBehavior,
sh_glob: PatternOperatorBehavior,
) -> GlobPatternBehavior
pub const fn from_parts( extended_glob: PatternOperatorBehavior, ksh_glob: PatternOperatorBehavior, sh_glob: PatternOperatorBehavior, ) -> GlobPatternBehavior
Creates a pattern behavior from its operator-family states.
Sourcepub fn extended_glob(self) -> PatternOperatorBehavior
pub fn extended_glob(self) -> PatternOperatorBehavior
Returns whether zsh extended glob operators such as #, ~, and ^ are active.
Sourcepub fn ksh_glob(self) -> PatternOperatorBehavior
pub fn ksh_glob(self) -> PatternOperatorBehavior
Returns whether ksh-style glob operators such as @(...) are active.
Sourcepub fn sh_glob(self) -> PatternOperatorBehavior
pub fn sh_glob(self) -> PatternOperatorBehavior
Returns whether sh-compatible glob parsing is active.