pub enum PathnameExpansionBehavior {
Disabled,
LiteralGlobsOnly,
LiteralGlobsOnlyOrDisabled,
SubstitutionResultsWhenUnquoted,
Ambiguous,
}Expand description
Option-sensitive shell behavior enums reused by linter facts and rules. Whether pathname expansion applies to literal globs and substitution results.
Variants
Disabled
Pathname expansion does not apply.
LiteralGlobsOnly
Literal glob characters are active, but substitution results are not globbed.
LiteralGlobsOnlyOrDisabled
Runtime option state may enable literal glob expansion, but substitution results stay plain.
SubstitutionResultsWhenUnquoted
Unquoted substitution results can also trigger pathname expansion.
Ambiguous
Runtime option state may select either behavior family.
Implementations
Sourceimpl PathnameExpansionBehavior
impl PathnameExpansionBehavior
Sourcepub fn literal_globs_can_expand(self) -> bool
pub fn literal_globs_can_expand(self) -> bool
Returns whether literal glob characters may trigger pathname expansion.
Sourcepub fn unquoted_substitution_results_can_glob(self) -> bool
pub fn unquoted_substitution_results_can_glob(self) -> bool
Returns whether unquoted substitution results may be interpreted as globs.